@@ -31,3 +31,20 @@ class DockerImages(ImagesGateway):
             logger.error(
                 f"Error listing images, docker must be running and added to PATH: {e}"
             )
+
+    def get_base_image(self, matching_image):
+        try:
+            client = docker.from_env()
+            image_details = client.api.inspect_image(matching_image.id)
+            labels = image_details.get("Config", {}).get("Labels", {})
+            source_image = labels.get("source-image")
+            if source_image:
+                logger.info(f"Base image for '{matching_image}' from source-image label: {source_image}")
+                return source_image
+
+            logger.warning(f"Base image not found for '{matching_image}'.")
+            return None
+
+        except Exception as e:
+            logger.error(f"Error getting base image: {e}")
+            return None
\ No newline at end of file
