@@ -16,20 +16,22 @@ from devsecops_engine_tools.engine_sca.engine_dependencies.src.infrastructure.en
 
 
 def runner_engine_dependencies(
-    dict_args, config_tool, secret_tool, devops_platform_gateway
+    dict_args, config_tool, secret_tool, devops_platform_gateway, sbom_tool_gateway
 ):
     try:
         tools_mapping = {
-            "XRAY": {"tool_run": XrayScan, "tool_deserializator": XrayDeserializator},
+            "XRAY": {"tool_run": XrayScan, "tool_deserializator": XrayDeserializator, "tool_sbom": sbom_tool_gateway},
             "DEPENDENCY_CHECK": {
                 "tool_run": DependencyCheckTool,
                 "tool_deserializator": DependencyCheckDeserialize,
+                "tool_sbom": sbom_tool_gateway
             },
         }
 
         selected_tool = config_tool["ENGINE_DEPENDENCIES"]["TOOL"]
         tool_run = tools_mapping[selected_tool]["tool_run"]()
         tool_deserializator = tools_mapping[selected_tool]["tool_deserializator"]()
+        tool_sbom = tools_mapping[selected_tool]["tool_sbom"]
 
         return init_engine_dependencies(
             tool_run,
@@ -37,7 +39,8 @@ def runner_engine_dependencies(
             tool_deserializator,
             dict_args,
             secret_tool,
-            config_tool["ENGINE_DEPENDENCIES"]["TOOL"],
+            config_tool,
+            tool_sbom
         )
 
     except Exception as e:
