@@ -19,8 +19,12 @@ logger = MyLogger.__call__(**settings.SETTING_LOGGER).get_logger()
 
 
 class DependencyCheckTool(ToolGateway):
+    def __init__(self):
+        self.download_tool_called = False
+
     def download_tool(self, cli_version):
         try:
+            self.download_tool_called = True
             url = f"https://github.com/jeremylong/DependencyCheck/releases/download/v{cli_version}/dependency-check-{cli_version}-release.zip"
             response = requests.get(url, allow_redirects=True)
             home_directory = os.path.expanduser("~")
@@ -66,13 +70,12 @@ class DependencyCheckTool(ToolGateway):
             command = [
                 command_prefix,
                 "--format",
-                "JSON",
-                "--format",
                 "XML",
                 "--nvdApiKey",
                 token,
                 "--scan",
                 file_to_scan,
+                "--noupdate"
             ]
 
             if not token:
@@ -82,11 +85,10 @@ class DependencyCheckTool(ToolGateway):
                 command = [
                     command_prefix,
                     "--format",
-                    "JSON",
-                    "--format",
                     "XML",
                     "--scan",
                     file_to_scan,
+                    "--noupdate"
                 ]
 
             subprocess.run(command, capture_output=True, check=True)
